@@ -9,7 +9,7 @@ neighborhoods. The aim of this script is to resolve conflict files of both
 types.
 """
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 # pylint: disable=C0103, C0111, W0105, W0141, W0142
 
@@ -18,22 +18,23 @@ import filecmp
 import logging as logger
 import os
 import re
+import shlex
+import shutil
+import string
+import subprocess
+import tarfile
+from collections import OrderedDict
+from pathlib import Path
+try:
+    from enum import IntEnum
+except ImportError:
+    from flufl.enum import IntEnum
 try:
     # noinspection PyUnresolvedReferences
     from send2trash import send2trash
     can_delete_to_trash = True
 except ImportError:
     can_delete_to_trash = False
-import shlex
-import shutil
-import string
-import subprocess
-import tarfile
-from pathlib import Path
-try:
-    from enum import IntEnum
-except ImportError:
-    from flufl.enum import IntEnum
 
 
 class Keep(IntEnum):
@@ -190,7 +191,8 @@ class ConflictResolver:
         return Path(result)
 
     def conflict_files(self):
-        return (f for f in self.root.rglob('*') if self.is_conflict_file(f))
+        yield from sorted(set(
+            f for f in self.root.rglob('*') if self.is_conflict_file(f)))
 
     def resolve(self, conflict_file_path):
         normal_file_path = self.normal_file(conflict_file_path)
@@ -343,10 +345,12 @@ class ListConflictResolver(ConflictResolver):
         self.list_normal = list_normal
 
     def resolve_all(self):
-        for f in self.conflict_files():
-            print(f)
+        for conflict_file in self.conflict_files():
+            print(conflict_file)
             if self.list_normal:
-                print(self.normal_file(f))
+                normal_file = self.normal_file(conflict_file)
+                if normal_file.exists():
+                    print(normal_file)
 
 
 class ListAllConflictResolver(ListConflictResolver):
@@ -417,6 +421,10 @@ def parse_arguments():
     deleter_group.add_argument('-t', '--trash', action=TrashDeleterAction,
                                help="send deleted files to trash")
     conflict_resolver_group = parser.add_mutually_exclusive_group()
+    conflict_resolver_group.add_argument('-I', '--non-interactive',
+                                         action=ConflictResolverAction,
+                                         help="skip \"hard\" files, don't ask "
+                                              "questions")
     conflict_resolver_group.add_argument('-c', '--compare',
                                          action=CompareConflictResolverAction,
                                          help="compare conflict files to "
@@ -427,7 +435,7 @@ def parse_arguments():
     conflict_resolver_group.add_argument('-l', '--list',
                                          action=ListConflictResolverAction,
                                          help="list conflict files")
-    conflict_resolver_group.add_argument('-al', '--list-all',
+    conflict_resolver_group.add_argument('-L', '--list-all',
                                          action=ListAllConflictResolverAction,
                                          help="list conflict files and "
                                               "their corresponding normal "
